import { Duration } from 'aws-cdk-lib';
import { ApiDestination, Connection, IEventBus } from 'aws-cdk-lib/aws-events';
import { ISecret } from 'aws-cdk-lib/aws-secretsmanager';
import { IStateMachine } from 'aws-cdk-lib/aws-stepfunctions';
import { IConstruct } from 'constructs';
import { IssueHandlerOverride } from '../issue-handler-override';
import { IIssueHandler } from '../issue-manager';
import { IssuePluginBase, IssuePluginBaseProps } from '../issue-plugin-base';
export interface DiscordOverrideOptions {
    readonly channel?: string;
    readonly mentions?: string[];
}
/**
 * Configuration controlling how Discord messages should be sent in response
 * to events.
 */
export interface DiscordProps extends IssuePluginBaseProps {
    readonly channel: string;
    readonly eventBus?: IEventBus;
    readonly mentions?: string[];
    readonly name?: string;
    readonly timeout?: Duration;
    readonly token: ISecret;
}
/**
 * A standardized implementation that allows Discord messages to be sent in
 * response to events detected in AWS.
 *
 * Intended for use with the `IssueManager` state machine which allows
 * arbitrary types of events to be processed into standard values and then
 * output or one of more issue tracking services.
 */
export declare class Discord extends IssuePluginBase implements IIssueHandler {
    static readonly DEFAULT_NAME: string;
    static readonly MESSAGES_ENDPOINT: string;
    /**
     * Internal collection of users or roles who should be mentioned by default
     * when sending a message to Discord.
     */
    private readonly _mentions;
    /**
     * The default Discord channel where messages processed by the handler should
     * be sent if no override is given.
     *
     * @group Inputs
     */
    readonly channel: string;
    /**
     * The event bus to use to trigger writes to the Jira instance.
     *
     * This integration formats a Jira API response and then sends it to a Jira
     * instance by means of an EventBridge Destination API and a specially
     * crafted event pattern. This is the event bus where the rule to trigger the
     * API will be added and the trigger event will be sent.
     */
    readonly eventBus?: IEventBus;
    /**
     * The human friendly name that can be used to identify the plugin.
     *
     * @group Inputs
     */
    readonly name: string;
    /**
     * The length of time that the State Machine that handles creation of Jira
     * tickets is allowed to run before timing out.
     *
     * @group Inputs
     */
    readonly timeout?: Duration;
    /**
     * The token for a Discord bot that has permissions to post in the
     * destination channels. The secret should be in JSON format and contain the
     * key:
     *
     * token: The token for the bot that has permissions to post in the
     * destination Discord channels.
     *
     * @group Inputs
     */
    readonly token: ISecret;
    /**
     * Collection of users or roles who should be mentioned by default when
     * sending a message to Discord.
     */
    get mentions(): string[];
    /**
     * Destination pointing to a Jira instance where tickets are to be created.
     */
    readonly apiDestination: ApiDestination;
    /**
     * API connection providing details of how to communicate with the configured
     * Jira instance.
     */
    readonly connection: Connection;
    /**
     * The State Machine that handles creating a Jira ticket for a passed issue.
     *
     * Internally this state machine uses the AWS managed `AWS-CreateJiraIssue`
     * SSM Automation document.
     *
     * @group Resources
     */
    readonly handler: IStateMachine;
    /**
     * Creates a new instance of the JiraTicket class.
     *
     * @param scope A CDK Construct that will serve as this resource's parent in
     * the construct tree.
     * @param id A name to be associated with the stack and used in resource
     * naming. Must be unique within the context of 'scope'.
     * @param props Arguments related to the configuration of the resource.
     */
    constructor(scope: IConstruct, id: string, props: DiscordProps);
    buildEventOverrides(options: DiscordOverrideOptions): IssueHandlerOverride;
}
