import { Duration } from 'aws-cdk-lib';
import { ApiDestination, Connection, IEventBus } from 'aws-cdk-lib/aws-events';
import { ISecret } from 'aws-cdk-lib/aws-secretsmanager';
import { Chain, IStateMachine } from 'aws-cdk-lib/aws-stepfunctions';
import { IConstruct } from 'constructs';
import { IssueHandlerOverride } from '../issue-handler-override';
import { IIssueHandler } from '../issue-manager';
import { IssuePluginBase, IssuePluginBaseProps } from '../issue-plugin-base';
export interface JiraTicketPriorityMap {
    readonly critical?: string;
    readonly default?: string;
    readonly high?: string;
    readonly info?: string;
    readonly low?: string;
    readonly medium?: string;
}
export interface JiraTicketOverrideOptions {
    readonly assignee?: string;
    readonly issuePriority?: string;
    readonly issueType?: string;
    readonly project?: string;
}
/**
 * Configuration controlling how Jira tickets should be created in response
 * to events.
 */
export interface JiraTicketProps extends IssuePluginBaseProps {
    readonly assignee?: string;
    readonly credentials: ISecret;
    readonly eventBus?: IEventBus;
    readonly issueType: string;
    readonly jiraUrl: string;
    readonly name?: string;
    readonly project: string;
    readonly priorityMap: JiraTicketPriorityMap;
    readonly timeout?: Duration;
}
/**
 * A standardized implementation that allows Jira tickets to be created in
 * response to events detected in AWS.
 *
 * Intended for use with the `IssueManager` state machine which allows
 * arbitrary types of events to be processed into standard values and then
 * output or one of more issue tracking services.
 *
 * @see [AWS-CreateJiraIssue](https://docs.aws.amazon.com/systems-manager-automation-runbooks/latest/userguide/automation-aws-createjiraissue.html)
 */
export declare class JiraTicket extends IssuePluginBase implements IIssueHandler {
    static readonly DEFAULT_NAME: string;
    private static buildSeverityCondition;
    /**
     * The default assignee that issues should be created with if no other
     * assignee is specified by the event that triggered the issue creation.
     *
     * @group Inputs
     */
    readonly assignee?: string;
    /**
     * The credentials to be used for connecting to Jira. The secret should be in
     * JSON format and contain the key:
     *
     * username: The name of the user issues should be created as.
     * password: A password or API key for the user specified in `username`.
     *
     * @group Inputs
     */
    readonly credentials: ISecret;
    /**
     * The event bus to use to trigger writes to the Jira instance.
     *
     * This integration formats a Jira API response and then sends it to a Jira
     * instance by means of an EventBridge Destination API and a specially
     * crafted event pattern. This is the event bus where the rule to trigger the
     * API will be added and the trigger event will be sent.
     */
    readonly eventBus?: IEventBus;
    /**
     * The default issue type that issues should be created as if no other type
     * is specified by the event that triggered the issue creation.
     *
     * @group Inputs
     */
    readonly issueType: string;
    /**
     * The URL of the Jira instance where tickets should be created.
     *
     * @group Inputs
     */
    readonly jiraUrl: string;
    /**
     * The human friendly name that can be used to identify the plugin.
     *
     * @group Inputs
     */
    readonly name: string;
    /**
     * A mapping of the standard severities supported by issue manager to
     * priority levels supported by the destination Jira instance.
     *
     * @group Inputs
     */
    readonly priorityMap: JiraTicketPriorityMap;
    /**
     * The name of the default project to use for creating issues if no other
     * project is specified by the event that triggered the issue creation.
     *
     * @group Inputs
     */
    readonly project: string;
    /**
     * The length of time that the State Machine that handles creation of Jira
     * tickets is allowed to run before timing out.
     *
     * @group Inputs
     */
    readonly timeout?: Duration;
    /**
     * Destination pointing to a Jira instance where tickets are to be created.
     */
    readonly apiDestination: ApiDestination;
    /**
     * API connection providing details of how to communicate with the configured
     * Jira instance.
     */
    readonly connection: Connection;
    /**
     * The State Machine that handles creating a Jira ticket for a passed issue.
     *
     * Internally this state machine uses the AWS managed `AWS-CreateJiraIssue`
     * SSM Automation document.
     *
     * @group Resources
     */
    readonly handler: IStateMachine;
    /**
     * Creates a new instance of the JiraTicket class.
     *
     * @param scope A CDK Construct that will serve as this resource's parent in
     * the construct tree.
     * @param id A name to be associated with the stack and used in resource
     * naming. Must be unique within the context of 'scope'.
     * @param props Arguments related to the configuration of the resource.
     */
    constructor(scope: IConstruct, id: string, props: JiraTicketProps);
    buildSeverityMap(): Chain;
    buildEventOverrides(options: JiraTicketOverrideOptions): IssueHandlerOverride;
}
