import { Construct, IConstruct } from 'constructs';
import { RuleGroup, RuleGroupProps } from './rule-group';
/**
 * The details that are needed to configure an APS rule groups namespace that
 * will consume a rule group configuration.
 */
export interface RuleGroupConfigurationDetails {
    /**
     * The content of the rules configuration definition, in the format of an APS
     * rules configuration file.
     *
     * @see [Creating a rules file](https://docs.aws.amazon.com/prometheus/latest/userguide/AMP-ruler-rulesfile.html)
     */
    readonly content: string;
}
/**
 * Represents a rules configuration that can be consumed by Amazon Managed
 * Service for Prometheus when creating a rule groups namespace.
 */
export interface IRuleGroupConfiguration extends IConstruct {
    /**
     * Associates the configuration with a resource that is handling the creation
     * of an APS rule groups namespace.
     *
     * @param scope The construct handling the configuration of an APS rule
     * groups namespace that will be consuming this configuration.
     * @returns Rule group configuration details.
     */
    bind(scope: IConstruct): RuleGroupConfigurationDetails;
}
/**
 * Generic base class for Prometheus rules configurations that provides common
 * functionality shared by both constructed and imported configurations.
 */
declare abstract class RuleGroupConfigurationBase extends Construct implements IRuleGroupConfiguration {
    /**
     * Associates the configuration with a resource that is handling the creation
     * of an APS rule groups namespace.
     *
     * @param scope The construct handling the configuration of an APS rule
     * groups namespace that will be consuming this configuration.
     * @returns Rule group configuration details.
     */
    abstract bind(scope: IConstruct): RuleGroupConfigurationDetails;
}
/**
 * Configuration options for a Prometheus rule group configuration.
 */
export interface RuleGroupConfigurationProps {
}
/**
 * Represents a rules file definition that can be consumed by Amazon Managed
 * Service for Prometheus.
 *
 * @see [RuleGroupsNamespace Data](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-aps-rulegroupsnamespace.html#cfn-aps-rulegroupsnamespace-data)
 * @see [Creating a rules file](https://docs.aws.amazon.com/prometheus/latest/userguide/AMP-ruler-rulesfile.html)
 */
export declare class RuleGroupConfiguration extends RuleGroupConfigurationBase {
    /**
     * Imports an APS rules configuration using a raw string.
     *
     * The string should be in YAML format and follow the specification expected
     * by the `aps:CreateRuleGroupsNamespace` API call.
     *
     * @see [Rules file specification](https://docs.aws.amazon.com/prometheus/latest/userguide/AMP-ruler-rulesfile.html)
     *
     * @param scope The construct handling the configuration of a rule groups
     * namespace that will consume the rendered configuration.
     * @param id A name to be associated with the stack and used in resource
     * naming. Must be unique within the context of 'scope'.
     * @param content The raw string content of a rule groups configuration.
     * @returns An object that can be used to configure a rule groups namespace
     * for APS.
     */
    static fromContent(scope: IConstruct, id: string, content: string): IRuleGroupConfiguration;
    /**
     * Imports an APS rules file from the local filesystem.
     *
     * The file should be in YAML format and follow the specification expected by
     * the `aps:CreateRuleGroupsNamespace` API call.
     *
     * @see [Rules file specification](https://docs.aws.amazon.com/prometheus/latest/userguide/AMP-ruler-rulesfile.html)
     *
     * @param scope The construct handling the configuration of a rule groups
     * namespace that will consume the rendered configuration.
     * @param id A name to be associated with the stack and used in resource
     * naming. Must be unique within the context of 'scope'.
     * @param path The path to the file containing the rule group definitions.
     * @returns An object that can be used to configure a rule groups namespace
     * for APS.
     */
    static fromRulesFile(scope: IConstruct, id: string, path: string): IRuleGroupConfiguration;
    /**
     * Internal collection of rule groups that are part of this configuration.
     */
    private _ruleGroups;
    /**
     * Collection of rule groups that are part of this configuration.
     */
    get ruleGroups(): RuleGroup[];
    /**
     * Creates a new instance of the RuleGroupConfiguration class.
     *
     * @param scope A CDK Construct that will serve as this construct's parent in
     * the construct tree.
     * @param id A name to be associated with the stack and used in resource
     * naming. Must be unique within the context of 'scope'.
     * @param _props Arguments related to the configuration of the construct.
     */
    constructor(scope: IConstruct, id: string, _props?: RuleGroupConfigurationProps);
    /**
     * Adds a new rule group to the configuration.
     *
     * @param id A name to be associated with the stack and used in resource
     * naming. Must be unique within the context of 'scope'.
     * @param options Configuration options for the new rule group being added.
     * @returns The rule group that was added.
     */
    addRuleGroup(id: string, options?: RuleGroupProps): RuleGroup;
    /**
     * Associates the configuration with a resource that is handling the creation
     * of an APS rule groups namespace.
     *
     * @param scope The construct handling the configuration of an APS rule
     * groups namespace that will be consuming this configuration.
     * @returns Rule group configuration details.
     */
    bind(scope: IConstruct): RuleGroupConfigurationDetails;
}
export {};
