import { ArnFormat, Resource, ResourceProps } from 'aws-cdk-lib';
import { CfnDetector } from 'aws-cdk-lib/aws-guardduty';
import { IConstruct } from 'constructs';
import { IFeature } from './lib/features';
/**
 * Specifies how frequently updated findings are exported.
 *
 * @see [Detector FindingPublishingFrequency](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-detector.html#cfn-guardduty-detector-findingpublishingfrequency)
 */
export declare class FindingPublishingFrequency {
    /**
     * Publish findings every fifteen minutes.
     */
    static readonly FIFTEEN_MINUTES: FindingPublishingFrequency;
    /**
     * Publish findings every hour.
     */
    static readonly ONE_HOUR: FindingPublishingFrequency;
    /**
     * Publish findings every six hours.
     */
    static readonly SIX_HOURS: FindingPublishingFrequency;
    /**
     * Escape hatch for specifying custom publishing frequency values.
     *
     * This is primarily intended in case additional options are added and
     * support for those values has not yet been officially added.
     *
     * Where possible it is recommended that the existing provided values be
     * used.
     *
     * @param label The label for the publishing frequency value as would be
     * expected by CloudFormation.
     * @returns An object that can be used for setting the publishing frequency
     * for a detector resource.
     */
    static of(label: string): FindingPublishingFrequency;
    /**
     * The label for the publishing frequency value as would be expected by
     * CloudFormation.
     */
    readonly label: string;
    /**
     * Creates a new instance of the FindingPublishingFrequency class.
     *
     * @param label The label for the publishing frequency value as would be
     * expected by CloudFormation.
     */
    private constructor();
}
/**
 * Represents a GuardDuty detector in AWS.
 */
export interface IDetector {
    /**
     * The Amazon Resource Name (ARN) of the GuardDuty detector.
     */
    readonly detectorArn: string;
    /**
     * The ID generated by AWS for the GuardDuty detector.
     */
    readonly detectorId: string;
}
/**
 * Configuration for importing an existing GuardDuty detector.
 */
export interface DetectorAttributes {
    /**
     * The Amazon Resource Name (ARN) of the GuardDuty detector.
     */
    readonly detectorArn?: string;
    /**
     * The ID generated by AWS for the GuardDuty detector.
     */
    readonly detectorId?: string;
}
/**
 * Optional configuration for the detector resource.
 */
export interface DetectorOptions {
    /**
     * Specifies whether the detector is to be enabled on creation.
     *
     * @see [Detector Enable](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-detector.html#cfn-guardduty-detector-enable)
     */
    readonly enabled?: boolean;
    /**
     * Collection of additional features to be configured on the detector.
     *
     * @see [Detector Features](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-detector.html#cfn-guardduty-detector-features)
     */
    readonly features?: IFeature[];
    /**
     * Specifies how frequently updated findings are exported.
     *
     * @see [Detector FindingPublishingFrequency](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-detector.html#cfn-guardduty-detector-findingpublishingfrequency)
     */
    readonly publishingFrequency?: FindingPublishingFrequency;
}
/**
 * Configuration for the dector resource.
 */
export interface DetectorProps extends ResourceProps, DetectorOptions {
}
/**
 * A base class providing common functionality between created and imported
 * detectors.
 */
declare abstract class DetectorBase extends Resource implements IDetector {
    /**
     * The Amazon Resource Name (ARN) of the GuardDuty detector.
     */
    abstract readonly detectorArn: string;
    /**
     * The ID generated by AWS for the GuardDuty detector.
     */
    abstract readonly detectorId: string;
    /**
     * Creates a new instance of the DetectorBase resource.
     *
     * @param scope A CDK Construct that will serve as this resource's parent in
     * the construct tree.
     * @param id A name to be associated with the stack and used in resource
     * naming. Must be unique within the context of 'scope'.
     * @param props Arguments related to the configuration of the resource.
     */
    constructor(scope: IConstruct, id: string, props?: ResourceProps);
}
/**
 * Represents a GuardDuty detector.
 *
 * A detector is an object that represents the GuardDuty service. A detector is
 * required for GuardDuty to become operational.
 *
 * @see [AWS::GuardDuty::Detector](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-detector.html)
 */
export declare class Detector extends DetectorBase {
    /**
     * The format this resource uses for it's Amazon Resource Name (ARN).
     */
    static readonly ARN_FORMAT: ArnFormat;
    /**
     * Imports an existing GuardDuty detector by specifying its Amazon Resource
     * Name (ARN).
     *
     * @param scope A CDK Construct that will serve as this resources's parent in
     * the construct tree.
     * @param id A name to be associated with the stack and used in resource
     * naming. Must be unique within the context of 'scope'.
     * @param detectorArn The ARN of the existing GuardDuty detector to be
     * imported.
     * @returns An object representing the imported GuardDuty detector.
     */
    static fromDetectorArn(scope: IConstruct, id: string, detectorArn: string): IDetector;
    /**
     * Imports an existing GuardDuty detector by explicitly specifying its
     * attributes.
     *
     * @param scope A CDK Construct that will serve as this resources's parent in
     * the construct tree.
     * @param id A name to be associated with the stack and used in resource
     * naming. Must be unique within the context of 'scope'.
     * @param attrs The attributes of the existing GuardDuty detector to be
     * imported.
     * @returns An object representing the imported GuardDuty detector.
     */
    static fromDetectorAttributes(scope: IConstruct, id: string, attrs: DetectorAttributes): IDetector;
    /**
     * Imports an existing GuardDuty detector by specifiying its AWS generated
     * ID.
     *
     * @param scope A CDK Construct that will serve as this resources's parent in
     * the construct tree.
     * @param id A name to be associated with the stack and used in resource
     * naming. Must be unique within the context of 'scope'.
     * @param detectorId The AWS generated ID of an existing GuardDuty detector
     * to be imported.
     * @returns An object representing the imported GuardDuty detector.
     */
    static fromDetectorId(scope: IConstruct, id: string, detectorId: string): IDetector;
    /**
     * Internal collection of additional features to be configured on the
     * detector.
     */
    private readonly _features;
    /**
     * Specifies whether the detector is to be enabled on creation.
     *
     * @see [Detector Enable](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-detector.html#cfn-guardduty-detector-enable)
     *
     * @group Inputs
     */
    readonly enabled: boolean;
    /**
     * Specifies how frequently updated findings are exported.
     *
     * @see [Detector FindingPublishingFrequency](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-detector.html#cfn-guardduty-detector-findingpublishingfrequency)
     *
     * @group Inputs
     */
    readonly publishingFrequency?: FindingPublishingFrequency;
    /**
     * Collection of additional features to be configured on the detector.
     *
     * @see [Detector Features](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-detector.html#cfn-guardduty-detector-features)
     *
     * @group Inputs
     */
    get features(): IFeature[];
    /**
     * The underlying Detector CloudFormation resource.
     *
     * @see [AWS::GuardDuty::Detector](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-guardduty-detector.html)
     *
     * @group Resources
     */
    readonly resource: CfnDetector;
    /**
     * The Amazon Resource Name (ARN) of the GuardDuty detector.
     */
    readonly detectorArn: string;
    /**
     * The ID generated by AWS for the GuardDuty detector.
     */
    readonly detectorId: string;
    /**
     * Creates a new instance of the Detector resource.
     *
     * @param scope A CDK Construct that will serve as this resource's parent in
     * the construct tree.
     * @param id A name to be associated with the stack and used in resource
     * naming. Must be unique within the context of 'scope'.
     * @param props Arguments related to the configuration of the resource.
     */
    constructor(scope: IConstruct, id: string, props?: DetectorProps);
    /**
     * Configures a feature to be enabled on the detector.
     *
     * @param feature The feature to be configured.
     * @returns The detector on which the feature was configured.
     */
    addFeature(feature: IFeature): Detector;
}
export {};
